@@ -260,6 +260,7 @@ namespace {
             ".aac",
             ".aacp",
             ".ac3",
+            ".ac4",
             ".act",
             ".adts",
             ".aif",
@@ -298,6 +299,7 @@ namespace {
             ".dvr",
             ".dvr-ms",
             ".eac3",
+            ".ec3",
             ".evo",
             ".f4a",
             ".f4b",
@@ -315,6 +317,7 @@ namespace {
             ".hdmov",
             ".heic",
             ".heif",
+            ".hif",
             ".iamf",
             ".ico",
             ".ifo",
